@@ -9,13 +9,13 @@ class Gateway:
 
         self._response = Response()
 
-    def change_config(self, data):
+    def change_config(self):
         
-        self._conf = ConfController(data)
-        
-        if self._conf.get_erros():
-
-            print(self._conf.get_erros())
+        self._message = {'token': self._token}
+        self._response.send_message(json.dumps(self._message))
+        self._message = self._response.get_message()
+        self._conf = ConfController(json.loads(self._message))
+        self._conf.execute()
 
     def search_printers(self):
 
@@ -27,6 +27,15 @@ class Gateway:
 
         self._message = {'token': self._token}
         self._response.send_message(json.dumps(self._message))
+        self._message = self._response.get_message()
+        self._print = PrintController()
+        self._print.print_data(json.loads(self._message))
+
+    def emitir_nota_fiscal(self):
+
+        self._message = {'token': self._token}
+        self._response.send_message(json.dumps(self._message))
+        self._message = self._response.get_message()
     
     def set_erro(self, erro):
 
